@@ -2043,9 +2043,9 @@ class VariableOsInstallMbr(LocationHelper, Variable):
 
     def uncompatible(self):
         """
-        Network setting up unavailable for flash installation
+        Опция несовместима с использованием UEFI
         """
-        if self.Get('os_install_uefi_set') == "on":
+        if self.Get('os_install_uefi_set') == "on" and self.Get():
             return _("MBR is not used with the UEFI bootloader")
         if self.Get('cl_autopartition_set') == "on":
             return \
