@@ -213,10 +213,11 @@ class Wsdl(WsdlBase):
                                         'os_install_mbr',
                                         'os_install_uefi_set',
                                         'os_install_kernel_scheduler',
-                                        'cl_grub_remove_pwd_set',
-                                        'os_install_grub_terminal'),
-                                    expert=(
+                                        'os_install_grub_terminal',
                                         'cl_grub_pwd',
+                                        'cl_grub_remove_pwd_set',
+                                    ),
+                                    expert=(
                                         'cl_templates_locate',
                                         'cl_dispatch_conf',
                                         'cl_verbose_set'),
